use scootaloo::parse_toml;

#[test]
fn test_parse_good_toml() {
    let parse_good_toml = parse_toml("tests/good_test.toml");

    assert_eq!(
        parse_good_toml.scootaloo.db_path,
        "/var/random/scootaloo.sqlite"
    );
    assert_eq!(parse_good_toml.scootaloo.cache_path, "/tmp/scootaloo");

    assert_eq!(parse_good_toml.twitter.consumer_key, "rand consumer key");
    assert_eq!(parse_good_toml.twitter.consumer_secret, "secret");
    assert_eq!(parse_good_toml.twitter.access_key, "rand access key");
    assert_eq!(parse_good_toml.twitter.access_secret, "super secret");

    assert_eq!(
        &parse_good_toml
            .mastodon
            .get("tamerelol")
            .unwrap()
            .twitter_screen_name,
        "tamerelol"
    );
    assert_eq!(
        &parse_good_toml.mastodon.get("tamerelol").unwrap().base,
        "https://m.nintendojo.fr"
    );
    assert_eq!(
        &parse_good_toml.mastodon.get("tamerelol").unwrap().client_id,
        "rand client id"
    );
    assert_eq!(
        &parse_good_toml
            .mastodon
            .get("tamerelol")
            .unwrap()
            .client_secret,
        "secret"
    );
    assert_eq!(
        &parse_good_toml.mastodon.get("tamerelol").unwrap().redirect,
        "urn:ietf:wg:oauth:2.0:oob"
    );
    assert_eq!(
        &parse_good_toml.mastodon.get("tamerelol").unwrap().token,
        "super secret"
    );
}

#[test]
#[should_panic(
    expected = "Cannot open config file tests/no_file.toml: No such file or directory (os error 2)"
)]
fn test_parse_no_toml() {
    let _parse_no_toml = parse_toml("tests/no_file.toml");
}

#[test]
#[should_panic(
    expected = "Cannot parse TOML file tests/bad_test.toml: expected an equals, found a newline at line 1 column 5"
)]
fn test_parse_bad_toml() {
    let _parse_bad_toml = parse_toml("tests/bad_test.toml");
}
